Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(613)

Unified Diff: chrome/browser/first_run/first_run.h

Issue 20483002: Merge 3 different ways of obtaining first run state into a single one. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/first_run/first_run.h
diff --git a/chrome/browser/first_run/first_run.h b/chrome/browser/first_run/first_run.h
index 7be708fa15fd1c123131ccb754386a5af564864d..4d1628c4427f9d029c602aff73cdf19f3944dd4b 100644
--- a/chrome/browser/first_run/first_run.h
+++ b/chrome/browser/first_run/first_run.h
@@ -62,9 +62,8 @@ enum FirstRunBubbleOptions {
};
enum ProcessMasterPreferencesResult {
- DO_FIRST_RUN_TASKS = 0, // Should do the first run tasks.
- SKIP_FIRST_RUN_TASKS, // Should skip the first run tasks.
- EULA_EXIT_NOW, // Should immediately exit due to EULA flow.
+ FIRST_RUN_PROCEED = 0, // Proceed with first run.
+ EULA_EXIT_NOW, // Should immediately exit due to EULA flow.
};
// See ProcessMasterPreferences for more info about this structure.

Powered by Google App Engine
This is Rietveld 408576698